.euro, .nombre { font-family: 'Source Code Pro', monospace; text-align: right; }
.euro:after { content: ' €'; }
.at:after { content: '@'; }
.dot:after { content: '.'; }
.mail:after { content: '>'; }
.mail:before { content: '<'; }
